@@ -6,7 +6,7 @@ from .paginations import (
     BasePaginatorAbstract, LimitOffsetResultPaginator, LimitOffsetObjectsPaginator, LimitOffsetItemsPaginator
 )
 
-__all__ = [
+__ALL__ = [
     BaseApiView,
     GetSerializerMixin, GetResponseMixin,
     BasePaginatorAbstract, LimitOffsetResultPaginator, LimitOffsetObjectsPaginator, LimitOffsetItemsPaginator
